@@ -2,8 +2,12 @@
 
 from .mini_plugin_generator import generate_mini_plugin
 
+plugin_generators = {
+    'mini_plugin': generate_mini_plugin
+}
 
-def generate(plugin_type, **params):
+
+def generate_plugin(plugin_type, **params):
     """ Generates a directory with jana plugin.
 
     Known plugin types:
@@ -15,5 +19,11 @@ def generate(plugin_type, **params):
         path        - Path to the directory with plugin, otherwise current dir is used
 
     """
-    if plugin_type == "mini_plugin":
-        return generate_mini_plugin(**params)
\ No newline at end of file
+
+    # check if this plugin generator is known
+    if plugin_type not in plugin_generators:
+        message = f"plugin_type provided to generate_plugin function is unknown. Please use one of: " +\
+                    " ".join([name for name in plugin_generators.keys()])
+        raise ValueError(message)
+
+    plugin_generators[plugin_type](**params)
\ No newline at end of file
